Module decode

Module decode 

Decoding routines.

Functions

calculate_decoded_len
Calculate the amount of bytes required to store base64-encoded input after decoding it.
decode_into
Decode base64-encoded input into the provided slice.
decode_into_unchecked
Decode base64-encoded input into the provided slice without validating its length.
decode_to_vec
Decode base64-encoded input into a new Vec<u8>.