Module error

Module error 

Error types.

Enums

DecodeError
Errors than can occur while decoding.
DecodeIntoSliceError
Errors than can occur while decoding into a slice.
EncodeError
Errors than can occur while encoding.
EncodeIntoSliceError
Errors than can occur while encoding into a slice.